@@ -74,8 +74,7 @@ def logme(level, msg, exc_info=False):
 
 class LogRecorder(pylogging.Formatter):
     def __init__(self, logs, *args, **kwargs):
-        if sys.version_info >= (3, 8):
-            kwargs['validate'] = False
+        kwargs['validate'] = False
         super(LogRecorder, self).__init__(*args, **kwargs)
         self.logs = logs
 
@@ -95,15 +94,15 @@ class LogTest(testctx.TestContextTestCase):
             level=logging.INFO))
 
         # These write to the log on the priv side
-        logme(logging.DEBUG, u'test@DEBUG')
-        logme(logging.WARN, u'test@WARN')
+        logme(logging.DEBUG, 'test@DEBUG')
+        logme(logging.WARN, 'test@WARN')
 
         time.sleep(0.1)  # Hack to give logging thread a chance to run
 
         # logger.output is the resulting log on the unpriv side.
         # This should have been filtered based on (unpriv) loglevel.
-        self.assertNotIn(u'test@DEBUG', logger.output)
-        self.assertIn(u'test@WARN', logger.output)
+        self.assertNotIn('test@DEBUG', logger.output)
+        self.assertIn('test@WARN', logger.output)
 
     def test_record_data(self):
         logs = []
@@ -114,19 +113,19 @@ class LogTest(testctx.TestContextTestCase):
             # class/function, not an instance :(
             formatter=functools.partial(LogRecorder, logs)))
 
-        logme(logging.WARN, u'test with exc', exc_info=True)
+        logme(logging.WARN, 'test with exc', exc_info=True)
 
         time.sleep(0.1)  # Hack to give logging thread a chance to run
 
         self.assertEqual(1, len(logs))
 
         record = logs[0]
-        self.assertIn(u'test with exc', record.getMessage())
+        self.assertIn('test with exc', record.getMessage())
         self.assertIsNone(record.exc_info)
-        self.assertIn(u'TestException: with arg', record.exc_text)
+        self.assertIn('TestException: with arg', record.exc_text)
         self.assertEqual('PrivContext(cfg_section=privsep)',
                          record.processName)
-        self.assertIn(u'test_daemon.py', record.exc_text)
+        self.assertIn('test_daemon.py', record.exc_text)
         self.assertEqual(logging.WARN, record.levelno)
         self.assertEqual('logme', record.funcName)
 
@@ -139,7 +138,7 @@ class LogTest(testctx.TestContextTestCase):
             # class/function, not an instance :(
             formatter=functools.partial(LogRecorder, logs)))
 
-        logme(logging.WARN, u'test with exc', exc_info=True)
+        logme(logging.WARN, 'test with exc', exc_info=True)
 
         time.sleep(0.1)  # Hack to give logging thread a chance to run
 
@@ -167,6 +166,11 @@ class DaemonTest(base.BaseTestCase):
         channel = mock.NonCallableMock()
         context = get_fake_context()
 
+        manager = mock.Mock()
+        manager.attach_mock(mock_setuid, "setuid")
+        manager.attach_mock(mock_setgid, "setgid")
+        expected_calls = [mock.call.setgid(84), mock.call.setuid(42)]
+
         d = daemon.Daemon(channel, context)
         d._drop_privs()
 
@@ -174,6 +178,8 @@ class DaemonTest(base.BaseTestCase):
         mock_setgid.assert_called_once_with(84)
         mock_setgroups.assert_called_once_with([])
 
+        assert manager.mock_calls == expected_calls
+
         self.assertCountEqual(
             [mock.call(True), mock.call(False)],
             mock_keepcaps.mock_calls)
